unit fnt5x12;

interface

uses Graph, Crt;

const
   HeightChar = 12;
   WidthChar  = 5;
   MaxChar    = 256; (* quantity of characters *)

type
   PFont = ^TFont;
   TFont = array[0..14 * (MaxChar - 1)] of Byte;

var
   FontBuf : PFont;
   CursorX,
   CursorY  : Byte;

function GetHCT(X1, X2: Integer; S: string): Integer;
   (* result: X coordinate for home of the string that the string put out
      to screen in center of line (X1;X2) *)

procedure OutStrXY(x, y: Integer; S:string);
   (* output string in (x;y) *)

procedure Locate(NewCursorX, NewCursorY : Integer);

procedure Print(s : string);

procedure PrintLn(s : string);

implementation

function GetHCT(X1, X2: Integer; S: string): Integer;
begin
   GetHCT := (X2 - X1 - Length(S) * WidthChar) div 2 + X1;
end;

procedure OutCharXY(x, y: Integer; c: Char);
var
   CC,                                    (* ASCII code of the character *)
   i,
   j  : Byte;
   CA : array[0..14 - 1] of Byte; (* buffer for the character *)
   Col: Word;                             (* color of the character *)
begin
   Col := GetColor;
   CC := Ord(c);
   for i := 0 to HeightChar - 1 do
      CA[i] := FontBuf^[CC * 14 + i];
   for i := 0 to HeightChar - 1 do
      for j := 0 to WidthChar - 1 do
         if (CA[i] and (128 shr j)) <> 0 then
            PutPixel(x + j, y + (i - 1), Col);
end;

procedure OutStrXY(x, y: Integer; s: string);
var
   i: Byte;
begin
   for i := 1 to Length(S) do
      OutCharXY(x + WidthChar * (i - 1), y, s[i]);
end;

procedure Locate(NewCursorX, NewCursorY : Integer);
begin
   CursorX := NewCursorX;
   CursorY := NewCursorY;
end;

procedure Print(s : string);
var
   i: Byte;
begin
   SetColor(TextAttr);
   SetFillStyle(SolidFill, TextAttr shr 4);
   for i := 1 to Length(S) do begin
      Bar((CursorX - 1) * WidthChar+(i-1)*WidthChar, (CursorY - 1) * HeightChar,
      (CursorX - 1) * WidthChar + i * WidthChar - 1, CursorY * HeightChar - 1);
      OutCharXY((CursorX - 1) * WidthChar + WidthChar * (i - 1), (CursorY - 1) * HeightChar + 1, s[i]);
   end;
   Locate(CursorX + Length(s), CursorY);
end;

procedure PrintLn(s : string);
begin
   Print(s);
   CursorX := 1;
   Inc(CursorY);
end;

var
   F : file;
   e : Integer;

begin
   New(FontBuf);
   Assign(F, '5x12.fnt');
   {$I-} Reset(F); {$I+}
   if Ioresult <> 0 then
      begin
      Writeln('Error :   Can not load font');
      Halt;
      end;
   Blockread(F, FontBuf^, FileSize(F), e);
   if e <> FileSize(F) then
      begin
      Writeln('Error :   Can not load font');
      Dispose(FontBuf);
      Halt;
      end;
   Locate(1, 1);
end.